@@ -97,7 +97,6 @@ class ApiKey:
         Parameters
         ----------
         data: ApiKeysPatchSchema
-
         """
         if data is not None:
             try:
@@ -481,7 +480,6 @@ class ApiKeys:
         tenantId: str
           The tenant ID of the API keys configuration to be retrieved.
         data: ApiKeysConfigPatchSchema
-
         """
         if data is not None:
             try:
@@ -539,7 +537,6 @@ class ApiKeys:
         startingAfter: str = None,
         status: Literal["active", "expired", "revoked"] = None,
         sub: str = None,
-        max_items: int = 20,
     ) -> ListableResource[ApiKey]:
         """
         Lists API keys for a given tenant ID.
@@ -587,7 +584,6 @@ class ApiKeys:
             cls=ApiKey,
             auth=self.auth,
             path="/api-keys",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -598,7 +594,6 @@ class ApiKeys:
         Parameters
         ----------
         data: ApiKeyBody
-
         """
         if data is not None:
             try:
