@@ -558,7 +558,6 @@ class Audits:
         sort: str = "-eventTime",
         source: str = None,
         userId: str = None,
-        max_items: int = 10,
     ) -> ListableResource[GetByIDResult]:
         """
         Finds and returns the persisted audit events for the given tenant.
@@ -614,6 +613,5 @@ class Audits:
             cls=GetByIDResult,
             auth=self.auth,
             path="/audits",
-            max_items=max_items,
             query_params=query_params,
         )
