@@ -101,7 +101,6 @@ class CollectionResultResponseBody:
         Removes an item from a collection.
         Removes an item from a collection.
 
-
         Parameters
         ----------
         itemId: str
@@ -121,7 +120,6 @@ class CollectionResultResponseBody:
         Returns an item in a specific collection.
         Finds and returns an item. See GET /items/{id}
 
-
         Parameters
         ----------
         itemId: str
@@ -174,7 +172,6 @@ class CollectionResultResponseBody:
         Retrieves items in a collection.
         Finds and returns items from a collection that the user has access to.
 
-
         Parameters
         ----------
         limit: int = 10
@@ -201,7 +198,6 @@ class CollectionResultResponseBody:
           The space's unique identifier (supports \'personal\' as spaceId).
         noActions: bool = False
           If set to true, the user's available actions for each item will not be evaluated meaning the actions-array will be omitted from the response (reduces response time).
-
         """
         query_params = {}
         if limit is not None:
@@ -245,11 +241,9 @@ class CollectionResultResponseBody:
         Adds an item to a collection.
         Adds an item to a collection and returns the item.
 
-
         Parameters
         ----------
         data: CollectionsAddCollectionItemRequestBody
-
         """
         if data is not None:
             try:
@@ -271,7 +265,6 @@ class CollectionResultResponseBody:
         Deletes a collection.
         Deletes a collection and removes all items from the collection.
 
-
         Parameters
         ----------
         """
@@ -289,11 +282,9 @@ class CollectionResultResponseBody:
         Updates a collection.
         Updates a collection and returns the new collection. Omitted and unsupported fields are ignored. To unset a field, provide the field's zero value.
 
-
         Parameters
         ----------
         data: CollectionsUpdateCollectionRequestBody
-
         """
         if data is not None:
             try:
@@ -1151,7 +1142,6 @@ class Collections:
         Retrieves the user's favorites collection.
         Finds and returns the user's favorites collection.
 
-
         Parameters
         ----------
         """
@@ -1168,7 +1158,6 @@ class Collections:
         Returns a collection.
         Finds and returns a collection.
 
-
         Parameters
         ----------
         collectionId: str
@@ -1198,13 +1187,11 @@ class Collections:
             "+createdAt", "-createdAt", "+name", "-name", "+updatedAt", "-updatedAt"
         ] = None,
         type: Literal["public", "private"] = None,
-        max_items: int = 10,
     ) -> ListableResource[CollectionResultResponseBody]:
         """
         Retrieves collections that the user has access to.
         Finds and returns the collections that the user can access. This endpoint does not return the user's favorites collection.
 
-
         Parameters
         ----------
         creatorId: str = None
@@ -1220,7 +1207,6 @@ class Collections:
         next: str = None
           The cursor to the next page of resources. Provide either the
           next or prev cursor, but not both.
-
         prev: str = None
           The cursor to the previous page of resources. Provide either the next or prev cursor, but not both.
         query: str = None
@@ -1230,7 +1216,6 @@ class Collections:
           The supported properties are createdAt, updatedAt, and name. A property
           must be prefixed by + or - to indicate ascending or descending sort order
           respectively.
-
         type: Literal["public", "private"] = None
           The case-sensitive string used to search for a collection by type.
         """
@@ -1266,7 +1251,6 @@ class Collections:
             cls=CollectionResultResponseBody,
             auth=self.auth,
             path="/collections",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -1277,11 +1261,9 @@ class Collections:
         Creates a new collection.
         Creates and returns a new collection. Collections can have the same name.
 
-
         Parameters
         ----------
         data: CollectionsCreateCollectionRequestBody
-
         """
         if data is not None:
             try:
