@@ -142,7 +142,6 @@ class CSPEntry:
         Parameters
         ----------
         data: CSPEntryContent
-
         """
         if data is not None:
             try:
@@ -470,7 +469,6 @@ class CspOrigins:
         ] = None,
         styleSrc: bool = None,
         workerSrc: bool = None,
-        max_items: int = 20,
     ) -> ListableResource[CSPEntry]:
         """
         Retrieves all CSP entries for a tenant
@@ -566,7 +564,6 @@ class CspOrigins:
             cls=CSPEntry,
             auth=self.auth,
             path="/csp-origins",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -577,7 +574,6 @@ class CspOrigins:
         Parameters
         ----------
         data: CSPEntryContent
-
         """
         if data is not None:
             try:
