@@ -748,7 +748,6 @@ class DataFiles:
         personal: bool = False,
         sort: Literal["spaceId", "+spaceId", "-spaceId"] = None,
         spaceId: str = None,
-        max_items: int = 20,
     ) -> ListableResource[ConnectionsResponse]:
         """
         Get the list of built-in connections used by the engine to load/write data files.
@@ -799,7 +798,6 @@ class DataFiles:
             cls=ConnectionsResponse,
             auth=self.auth,
             path="/data-files/connections",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -859,7 +857,6 @@ class DataFiles:
             "+modifiedDate",
             "-modifiedDate",
         ] = None,
-        max_items: int = 20,
     ) -> ListableResource[DataFileUploadResponse]:
         """
         Get descriptive info for the specified data files.
@@ -916,7 +913,6 @@ class DataFiles:
             cls=DataFileUploadResponse,
             auth=self.auth,
             path="/data-files",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -975,11 +971,7 @@ class DataFiles:
             Json_dict["tempContentFileId"] = tempContentFileId
         files_dict["Json"] = (None, json.dumps(Json_dict))
         response = self.auth.rest(
-            path="/data-files",
-            method="POST",
-            params={},
-            data=None,
-            files=files_dict,
+            path="/data-files", method="POST", params={}, data=None, files=files_dict
         )
         obj = DataFileUploadResponse(**response.json())
         obj.auth = self.auth
