@@ -500,7 +500,6 @@ class Groups:
         next: str = None,
         prev: str = None,
         sort: Literal["name", "+name", "-name"] = "+name",
-        max_items: int = 20,
     ) -> ListableResource[Group]:
         """
         Filter groups
@@ -544,7 +543,6 @@ class Groups:
             cls=Group,
             auth=self.auth,
             path="/groups/actions/filter",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -573,7 +571,6 @@ class Groups:
         Parameters
         ----------
         data: SettingsPatchSchema
-
         """
         if data is not None:
             try:
@@ -615,7 +612,6 @@ class Groups:
         prev: str = None,
         sort: str = None,
         totalResults: bool = None,
-        max_items: int = 20,
     ) -> ListableResource[Group]:
         """
         List groups.
@@ -660,6 +656,5 @@ class Groups:
             cls=Group,
             auth=self.auth,
             path="/groups",
-            max_items=max_items,
             query_params=query_params,
         )
