@@ -220,13 +220,11 @@ class ItemResultResponseBody:
             "+createdAt", "-createdAt", "+name", "-name", "+updatedAt", "-updatedAt"
         ] = None,
         type: Literal["public", "private"] = None,
-        max_items: int = 10,
     ) -> ListableResource[CollectionResultResponseBody]:
         """
         Returns the collections of an item.
         Finds and returns the collections of an item. This endpoint does not return the user's favorites collection.
 
-
         Parameters
         ----------
         limit: int = None
@@ -270,7 +268,6 @@ class ItemResultResponseBody:
             cls=CollectionResultResponseBody,
             auth=self.auth,
             path="/items/{itemId}/collections".replace("{itemId}", self.id),
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -297,13 +294,11 @@ class ItemResultResponseBody:
         sort: Literal[
             "+createdAt", "-createdAt", "+name", "-name", "+updatedAt", "-updatedAt"
         ] = None,
-        max_items: int = 10,
     ) -> ListableResource[CollectionResultResponseBody]:
         """
         Returns published items for a given item.
         Finds and returns the published items for a given item.
 
-
         Parameters
         ----------
         limit: int = None
@@ -339,7 +334,6 @@ class ItemResultResponseBody:
             cls=CollectionResultResponseBody,
             auth=self.auth,
             path="/items/{itemId}/publisheditems".replace("{itemId}", self.id),
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -348,7 +342,6 @@ class ItemResultResponseBody:
         Deletes an item.
         Deletes an item and removes the item from all collections.
 
-
         Parameters
         ----------
         """
@@ -364,11 +357,9 @@ class ItemResultResponseBody:
         Updates an item.
         Updates an item. Omitted and unsupported fields are ignored. To unset a field, provide the field's zero value.
 
-
         Parameters
         ----------
         data: ItemsUpdateItemRequestBody
-
         """
         if data is not None:
             try:
@@ -472,6 +463,7 @@ class ItemsSettingsPatch:
     """
 
     def __init__(self_, **kvargs):
+
         for k0, v in kvargs.items():
             k = k0.replace("-", "_")
             if k not in getattr(self_, "__annotations__", {}):
@@ -1171,7 +1163,6 @@ class Items:
         Returns tenant specific settings.
         Finds and returns the settings for the current tenant.
 
-
         Parameters
         ----------
         """
@@ -1193,7 +1184,6 @@ class Items:
         Parameters
         ----------
         data: ItemsSettingsPatch
-
         """
         if data is not None:
             try:
@@ -1215,7 +1205,6 @@ class Items:
         Returns an item.
         Finds and returns an item.
 
-
         Parameters
         ----------
         itemId: str
@@ -1269,13 +1258,11 @@ class Items:
         ] = None,
         spaceId: str = None,
         noActions: bool = False,
-        max_items: int = 10,
     ) -> ListableResource[ItemResultResponseBody]:
         """
         Retrieves items that the user has access to.
         Finds and returns items that the user has access to.
 
-
         Parameters
         ----------
         collectionId: str = None
@@ -1318,7 +1305,6 @@ class Items:
           The space's unique identifier (supports \'personal\' as spaceId).
         noActions: bool = False
           If set to true, the user's available actions for each item will not be evaluated meaning the actions-array will be omitted from the response (reduces response time).
-
         """
         query_params = {}
         if collectionId is not None:
@@ -1372,6 +1358,5 @@ class Items:
             cls=ItemResultResponseBody,
             auth=self.auth,
             path="/items",
-            max_items=max_items,
             query_params=query_params,
         )
