@@ -1151,7 +1151,6 @@ class Questions:
         qlik-web-integration-id: str = None
           This header is only required for external clients or mashups for QCS, this value of this property should be the id of the web integration set up for the external client/mashup
         data: QueryCreate
-
         """
         if data is not None:
             try:
@@ -1181,7 +1180,6 @@ class Questions:
             "-createdAt",
             "-updatedAt",
         ] = "+createdAt",
-        max_items: int = 100,
     ) -> ListableResource[NLMetricRecord]:
         """
         Returns NL metrics based on provided app IDs the user has access to.
@@ -1194,9 +1192,7 @@ class Questions:
           A cursor pointing to the page of data to retrieve.
         sort: Literal["createdAt", "updatedAt", "+createdAt", "+updatedAt", "-createdAt", "-updatedAt"] = "+createdAt"
           A single field from the data model on which to sort the response. The '+' or '-' operator may be used to specify ascending or desending order.
-
         data: NLMetricsRequest
-
         """
         if data is not None:
             try:
@@ -1221,6 +1217,5 @@ class Questions:
             cls=NLMetricRecord,
             auth=self.auth,
             path="/questions/actions/filter",
-            max_items=max_items,
             query_params=query_params,
         )
