@@ -122,7 +122,6 @@ class Task:
         """
         Delete a task.
 
-
         Parameters
         ----------
         """
@@ -137,7 +136,6 @@ class Task:
         """
         Update an existing task.
 
-
         Parameters
         ----------
         data: PutTaskBody
@@ -408,7 +406,6 @@ class ReloadTasks:
         """
         Find and return a task.
 
-
         Parameters
         ----------
         taskId: str
@@ -431,12 +428,10 @@ class ReloadTasks:
         next: str = None,
         partial: bool = None,
         prev: str = None,
-        max_items: int = 10,
     ) -> ListableResource[Task]:
         """
         Find and return the tasks that the user can access.
 
-
         Parameters
         ----------
         appId: str = None
@@ -472,7 +467,6 @@ class ReloadTasks:
             cls=Task,
             auth=self.auth,
             path="/reload-tasks",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -480,7 +474,6 @@ class ReloadTasks:
         """
         Create a task for a specified app.
 
-
         Parameters
         ----------
         data: PostTaskBody
