@@ -156,7 +156,7 @@ class Space:
         return obj
 
     def get_assignments(
-        self, limit: int = 10, next: str = None, prev: str = None, max_items: int = 10
+        self, limit: int = 10, next: str = None, prev: str = None
     ) -> ListableResource[Assignment]:
         """
         Retrieves the assignments of the space matching the query.
@@ -188,7 +188,6 @@ class Space:
             cls=Assignment,
             auth=self.auth,
             path="/spaces/{spaceId}/assignments".replace("{spaceId}", self.id),
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -677,6 +676,7 @@ class SpacePatch:
     """
 
     def __init__(self_, **kvargs):
+
         for k0, v in kvargs.items():
             k = k0.replace("-", "_")
             if k not in getattr(self_, "__annotations__", {}):
@@ -929,7 +929,6 @@ class Spaces:
         prev: str = None,
         sort: str = None,
         type: str = None,
-        max_items: int = 10,
     ) -> ListableResource[Space]:
         """
         Retrieves spaces that the current user has access to and match the query.
@@ -987,7 +986,6 @@ class Spaces:
             cls=Space,
             auth=self.auth,
             path="/spaces",
-            max_items=max_items,
             query_params=query_params,
         )
 
