@@ -170,7 +170,6 @@ class User:
         Parameters
         ----------
         data: JSONPatchArray
-
         """
         if data is not None:
             try:
@@ -348,7 +347,7 @@ class JSONPatch:
         "/preferredLocale",
         "/status",
     ] = None
-    value: object = None
+    value: str | bool | list[any] | list[JSONPatchAssignedRolesRefIDs] = None
 
     def __init__(self_, **kvargs):
 
@@ -378,6 +377,29 @@ class JSONPatchArray(List["JSONPatch"]):
             self_.append(JSONPatch(**e))
 
 
+@dataclass
+class JSONPatchAssignedRolesRefIDs:
+    """
+    represents a role entity stored in the database
+
+    Attributes
+    ----------
+    id: str
+      The unique role identitier
+    """
+
+    id: str = None
+
+    def __init__(self_, **kvargs):
+
+        if "id" in kvargs and kvargs["id"] is not None:
+            self_.id = kvargs["id"]
+        for k0, v in kvargs.items():
+            k = k0.replace("-", "_")
+            if k not in getattr(self_, "__annotations__", {}):
+                self_.__setattr__(k, v)
+
+
 @dataclass
 class Metadata:
     """
@@ -876,7 +898,6 @@ class Users:
         next: str = None,
         prev: str = None,
         sort: Literal["name", "+name", "-name"] = "+name",
-        max_items: int = 20,
     ) -> ListableResource[User]:
         """
         Filter users
@@ -924,7 +945,6 @@ class Users:
             cls=User,
             auth=self.auth,
             path="/users/actions/filter",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -1002,7 +1022,6 @@ class Users:
         status: Literal["active", "invited", "disabled", "deleted"] = "active",
         subject: str = None,
         tenantId: str = None,
-        max_items: int = 20,
     ) -> ListableResource[User]:
         """
         List users
@@ -1042,7 +1061,6 @@ class Users:
           ```
           name eq "Bob" or name eq "Alice" and (status eq "active" or status eq "disabled")
           ```
-
         limit: float = 20
           The number of user entries to retrieve.
         next: str = None
@@ -1125,7 +1143,6 @@ class Users:
             cls=User,
             auth=self.auth,
             path="/users",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -1137,7 +1154,6 @@ class Users:
         Parameters
         ----------
         data: UserPostSchema
-
         """
         if data is not None:
             try:
