@@ -173,7 +173,6 @@ class Webhook:
             "-triggeredAt",
         ] = "-triggeredAt",
         status: Literal["success", "fail"] = None,
-        max_items: int = 20,
     ) -> ListableResource[Delivery]:
         """
         Returns deliveries for a specific webhook
@@ -217,7 +216,6 @@ class Webhook:
             cls=Delivery,
             auth=self.auth,
             path="/webhooks/{id}/deliveries".replace("{id}", self.id),
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -242,7 +240,6 @@ class Webhook:
         Parameters
         ----------
         WebhookPatchData: list[WebhookPatch]
-
         """
         data = [asdict(elem) for elem in WebhookPatchData]
         self.auth.rest(
@@ -259,7 +256,6 @@ class Webhook:
         Parameters
         ----------
         data: WebhookDef
-
         """
         if data is not None:
             try:
@@ -749,7 +745,7 @@ class WebhookPatch:
         "/enabled",
         "/secret",
     ] = None
-    value: object = None
+    value: bool | int | object | str = None
 
     def __init__(self_, **kvargs):
 
@@ -833,7 +829,6 @@ class Webhooks:
         ] = "-createdAt",
         updatedByUserId: str = None,
         url: str = None,
-        max_items: int = 20,
     ) -> ListableResource[Webhook]:
         """
         Retrieves all webhooks entries for a tenant
@@ -901,7 +896,6 @@ class Webhooks:
             cls=Webhook,
             auth=self.auth,
             path="/webhooks",
-            max_items=max_items,
             query_params=query_params,
         )
 
@@ -912,7 +906,6 @@ class Webhooks:
         Parameters
         ----------
         data: WebhookDef
-
         """
         if data is not None:
             try:
