@@ -1,4 +1,3 @@
-import typing
 from urllib.parse import parse_qs, urlparse
 
 from .auth_type import AuthType
@@ -95,7 +94,6 @@ class Auth:
     ... with rpc_session.open() as rpc_client:
     ...     app = rpc_client.send("OpenDoc", -1, session_app_id)
     """
-    paginate_rest: typing.Callable[[str, str, typing.Dict, any], typing.Iterator[any]]
 
     code_verifier: str = None
     """oauth code verifier"""
@@ -108,7 +106,6 @@ class Auth:
         self.rest = RestClientInstance(RestClient(config))
         self.rpc_client = RpcClient(self.config)
         self.rpc = RpcClientInstance(self.rpc_client)
-        self.paginate_rest = self.rest.paginate_rest
 
     def generate_authorization_url(self, state: str = None) -> str:
         """
