@@ -3,7 +3,6 @@ import enum
 from dataclasses import dataclass
 from functools import reduce
 from typing import Callable
-from urllib.parse import parse_qs, urlparse
 
 import requests
 
@@ -187,39 +186,6 @@ class RestClient:
 
             return res
 
-    def paginate_rest(
-        self, path: str, method: str = "get", params: dict = {}, cls=None, max_items=10
-    ):
-        curr_params = params.copy()
-        if "limit" not in curr_params:
-            curr_params["limit"] = 10
-        done = False
-        yield_count = 0
-        while not done:
-            raw_response = self.rest(
-                method=method, path=path, data=None, params=curr_params
-            )
-            response = raw_response.json()
-            for i in response["data"]:
-                yield_item = i
-                if cls:
-                    yield_item = cls(**i)
-                yield yield_item
-                yield_count += 1
-                if yield_count == max_items:
-                    return
-            try:
-                url_str = response["links"]["next"]["href"]
-                # should be "next" but for users it is "startingAfter"
-                pagination_query_param = get_pagination_query_param(url_str=url_str)
-                if pagination_query_param:
-                    query_key, query_value = pagination_query_param
-                    curr_params[query_key] = query_value
-                else:
-                    done = True
-            except:
-                done = True
-
 
 class RestClientInstance:
     interceptors: Interceptors[ResponseInterceptor, RequestInterceptor]
@@ -227,15 +193,6 @@ class RestClientInstance:
     def __init__(self, restClient: RestClient) -> None:
         self._restClient = restClient
         self.interceptors = restClient._interceptors
-        self.paginate_rest = self._restClient.paginate_rest
 
     def __call__(self, **all: requests.Request) -> requests.Request:
         return self._restClient.rest(**all)
-
-
-def get_pagination_query_param(url_str: str):
-    query_dict = parse_qs(urlparse(url_str).query)
-    for k in ["next", "startingAfter"]:
-        if k in query_dict:
-            return k, query_dict[k][0]
-    return False
