@@ -106,13 +106,19 @@ class RpcSession:
         if event in self._listeners:
             self._listeners[event](*args)
         if event == "closed":
+            # call all the event closed listeners on all objects of session
+            for handle in self._id_listeners:
+                if "closed" in self._id_listeners[handle]:
+                    for closed_listener in self._id_listeners[handle]["closed"]:
+                        closed_listener(*args)
             # clear all listeners if session is closed
             self._listeners = {}
             self._id_listeners = {}
 
     def _emit_handle(self, handle, event, *args):
         if handle in self._id_listeners and event in self._id_listeners[handle]:
-            self._id_listeners[handle][event](*args)
+            for event_listener in self._id_listeners[handle][event]:
+                event_listener(*args)
         if event == "closed":
             # clear all listeners if handle is closed
             self._clear_listeners(handle)
@@ -215,8 +221,12 @@ class RpcSession:
 
     def on_handle(self, handle, event_name, listener):
         if handle not in self._id_listeners:
-            self._id_listeners[handle] = {}
-        self._id_listeners[handle][event_name] = listener
+            self._id_listeners[handle] = {event_name: [listener]}
+        else:
+            if event_name not in self._id_listeners[handle]:
+                self._id_listeners[handle][event_name] = [listener]
+            else:
+                self._id_listeners[handle][event_name].append(listener)
 
     def _clear_listeners(self, handle):
         if handle in self._id_listeners:
